@@ -1,9 +1,9 @@
 #' Lays out highchart widgets into a "grid", similar to
 #' \code{grid.arrange} from \code{gridExtra}
 #'
-#' @param ... either individual \code{highchart} objects or a mixture of
-#'     individual \code{highchart} objects
-#' and \code{list}s of \code{highchart} objects.
+#' @param ... either individual `highchart` objects or a mixture of
+#'     individual `highchart` objects
+#' and `list`s of `highchart` objects.
 #' @param ncol how many columns in the grid
 #' @param rowheight Height in px.
 #' 
@@ -15,10 +15,10 @@ hw_grid <- function(..., ncol = NULL, rowheight = NULL) {
   
   params <- list()
   
-  for (i in 1:length(input_list)) {
+  for (i in seq_len(length(input_list))) {
     x <- eval.parent(input_list[[i]])
     if (any(class(x) == "list")) {
-      for (j in 1:length(x)) {
+      for (j in seq_len(length(x))) {
         y <- eval(x[[j]])
         params[[length(params) + 1]] <- y
       }
@@ -49,7 +49,7 @@ hw_grid <- function(..., ncol = NULL, rowheight = NULL) {
     
   })
   
-  divgrid <- tags$div(class = "grid grid-pad", style = "with:100%", divs)
+  divgrid <- tags$div(class = "grid grid-pad", divs)
   
   class(divgrid) <- c(class(divgrid), "htmlwdwtgrid")
   
