@@ -1,5 +1,5 @@
 ## ------------------------------------------------------------------------
-library("highcharter")
+library(highcharter)
 
 highchart() %>% 
   hc_chart(type = "line") %>% 
@@ -53,33 +53,9 @@ hc <- highchart() %>%
 hc
 
 
-## ------------------------------------------------------------------------
-highchart() %>% 
-  hc_chart(polar = TRUE, type = "line") %>% 
-  hc_title(text = "Budget vs Spending") %>% 
-  hc_xAxis(categories = c("Sales", "Marketing", "Development",
-                          "Customer Support",  "Information Technology",
-                          "Administration"),
-           tickmarkPlacement = "on",
-           lineWidth = 0) %>% 
-  hc_yAxis(gridLineInterpolation = "polygon",
-           lineWidth = 0,
-           min = 0) %>% 
-  hc_series(
-    list(
-      name = "Allocated Budget",
-      data = c(43000, 19000, 60000, 35000, 17000, 10000),
-      pointPlacement = "on"
-    ),
-    list(
-      name = "Actual Spending",
-      data = c(50000, 39000, 42000, 31000, 26000, 14000),
-     pointPlacement = "on"
-    )
-  )
+## ---- message=FALSE------------------------------------------------------
+library(jsonlite)
 
 ## ------------------------------------------------------------------------
-library("jsonlite")
-
 toJSON(hc$x$hc_opts, pretty = TRUE, auto_unbox = TRUE)
 
